@@ -470,7 +470,7 @@ class Kubedev:
           f'{normalized_kubeconfig}:/tmp/kube_config',
           '--volume',
           f'{KubedevConfig.wsl_normalize(helm_chart, file_accessor, shell_executor)}:/app/helm-chart/',
-          'alpine/helm:2.16.9',
+          'alpine/helm:2.17.0',
           'upgrade',
           release_name,
           '/app/helm-chart/',
@@ -684,7 +684,13 @@ class Kubedev:
 
   def check_from_config(self, kubedev, commands, env_accessor, printer, file_accessor):
     def is_command(cmd):
-      return len(commands) == 0 or cmd in commands
+      return len(commands) == 0 or commands[0] == cmd
+
+    def get_apps():
+      if len(commands) > 1:
+        return commands[1:]
+      else:
+        return None
 
     result = True
 
@@ -705,12 +711,18 @@ class Kubedev:
             '❌ Required field "imagePullSecrets" is missing in kubedev.json', True)
         result = False
 
-    envs = KubedevConfig.get_all_envs(kubedev, build=is_command(
-        'build'), container=is_command('deploy') or is_command('template'), generics=is_command('deploy') or is_command('template')).keys()
-    for env in sorted(envs):
+    envs = KubedevConfig.get_all_envs(kubedev, apps=get_apps(), build=is_command(
+        'build'), container=is_command('deploy') or is_command('template'), generics=is_command('deploy') or is_command('template'))
+    envNames = envs.keys()
+    def getDocs(envDict: dict) -> str:
+      if 'documentation' in envDict and len(envDict['documentation'].strip()) > 0:
+        return envDict['documentation']
+      else:
+        return '(no documentation available)'
+    for env in sorted(envNames):
       if isinstance(env_accessor.getenv(env), type(None)):
         printer.print(
-            f'❌ Required environment variable "{env}" is not defined', True)
+            f'❌ Required environment variable "{env}" is not defined: {getDocs(envs[env])}', True)
         result = False
 
     if result:
@@ -1121,7 +1133,7 @@ class Kubedev:
                 '0',
                 '--volume',
                 f'{wslClusterConfig}:/tmp/kube_config',
-                'alpine/helm:2.16.9',
+                'alpine/helm:2.17.0',
                 '--kubeconfig',
                 '/tmp/kube_config',
                 'init',
