@@ -17,7 +17,7 @@ class KubedevConfig:
     }
 
   @staticmethod
-  def get_all_envs(kubedev, build, container, generics):
+  def get_all_envs(kubedev, apps, build, container, generics):
     envs = KubedevConfig.load_envs(
         kubedev, build=build, container=container)
     if generics:
@@ -26,10 +26,11 @@ class KubedevConfig:
       appTypes = ['deployments', 'cronjobs']
     for appType in appTypes:
       if appType in kubedev:
-        for (_, deployment) in kubedev[appType].items():
-          deploymentEnvs = KubedevConfig.load_envs(
-              deployment, build=build, container=container)
-          envs = {**envs, **deploymentEnvs}
+        for (appName, app) in kubedev[appType].items():
+          if apps is None or appName in apps:
+            appEnvs= KubedevConfig.load_envs(
+                app, build=build, container=container)
+            envs = {**envs, **appEnvs}
     return envs
 
   @staticmethod
@@ -67,7 +68,7 @@ class KubedevConfig:
     Returns shell parameters for helm commands in the form of ``--set <variable>="${<variable>}" ...''
     from a kubedev config.
     '''
-    (envs, extraEnvs) = KubedevConfig.prepare_envs(KubedevConfig.get_all_envs(kubedev, False, True, True), env_accessor=env_accessor)
+    (envs, extraEnvs) = KubedevConfig.prepare_envs(KubedevConfig.get_all_envs(kubedev, None, False, True, True), env_accessor=env_accessor)
     for var, value in variable_overrides.items():
       if (var in envs) or add_unknown_variable_overrides:
         envs[var] = {
